@@ -86,8 +86,10 @@ void cTextFile::writeCSVHeader(FILE *txtFile)
 	if (btnSelectLOC->value())       fprintf (txtFile, "%s", ",\"GRIDSQUARE\"");
 	if (btnSelectQSLrcvd->value())   fprintf (txtFile, "%s", ",\"QSL_RCVD\"");
 	if (btnSelectQSLsent->value())   fprintf (txtFile, "%s", ",\"QSL_SENT\"");
+	if (btnSelecteQSLrcvd->value())  fprintf (txtFile, "%s", ",\"EQSL_RCVD\"");
+	if (btnSelecteQSLsent->value())  fprintf (txtFile, "%s", ",\"EQSL_SENT\"");
 	if (btnSelectLOTWrcvd->value())  fprintf (txtFile, "%s", ",\"LOTW_RCVD\"");
-	if (btnSelectLOTWLsent->value())  fprintf (txtFile, "%s", ",\"LOTW_SENT\"");
+	if (btnSelectLOTWsent->value()) fprintf (txtFile, "%s", ",\"LOTW_SENT\"");
 	if (btnSelectNotes->value())     fprintf (txtFile, "%s", ",\"NOTES\"");
 	if (btnSelectSerialIN->value())  fprintf (txtFile, "%s", ",\"SERIAL RCVD\"");
 	if (btnSelectSerialOUT->value()) fprintf (txtFile, "%s", ",\"SERIAL_SENT\"");
@@ -133,9 +135,9 @@ int cTextFile::writeCSVFile (const char *fname, cQsoDb *db) {
 				if (btnSelectFreq->value())
 					fprintf (txtFile, ",\"%s\"", pRec->getField(FREQ));
 				if (btnSelectMode->value()) {
-					fprintf (txtFile, ",\"%s\"", adif2export(pRec->getField(MODE)).c_str());
-					if (!adif2submode(pRec->getField(MODE)).empty())
-						fprintf (txtFile, ",\%s\"", adif2submode(pRec->getField(MODE)).c_str());
+					fprintf (txtFile, ",\"%s\"", adif2export(pRec->getField(ADIF_MODE)).c_str());
+					if (!adif2submode(pRec->getField(ADIF_MODE)).empty())
+						fprintf (txtFile, ",\%s\"", adif2submode(pRec->getField(ADIF_MODE)).c_str());
 				}
 				if (btnSelectTX_pwr->value())
 					fprintf (txtFile, ",\"%s\"", pRec->getField(TX_PWR));
@@ -165,14 +167,22 @@ int cTextFile::writeCSVFile (const char *fname, cQsoDb *db) {
 					fprintf (txtFile, ",\"%s\"", pRec->getField(ITUZ));
 				if (btnSelectLOC->value())
 					fprintf (txtFile, ",\"%s\"", pRec->getField(GRIDSQUARE));
+
 				if (btnSelectQSLrcvd->value())
 					fprintf (txtFile, ",\"%s\"", pRec->getField(QSLRDATE));
 				if (btnSelectQSLsent->value())
 					fprintf (txtFile, ",\"%s\"", pRec->getField(QSLSDATE));
+
+				if (btnSelecteQSLrcvd->value())
+					fprintf (txtFile, ",\"%s\"", pRec->getField(EQSLRDATE));
+				if (btnSelecteQSLsent->value())
+					fprintf (txtFile, ",\"%s\"", pRec->getField(EQSLSDATE));
+
 				if (btnSelectLOTWrcvd->value())  
 					fprintf (txtFile, ",\"%s\"", pRec->getField(LOTWSDATE));
-				if (btnSelectLOTWLsent->value())
+				if (btnSelectLOTWsent->value())
 					fprintf (txtFile, ",\"%s\"", pRec->getField(LOTWSDATE));
+
 				if (btnSelectNotes->value()) {
 					string temp = pRec->getField(NOTES);
 					for (size_t n = 0; n < temp.length(); n++)
@@ -249,8 +259,13 @@ void cTextFile::writeTXTHeader(FILE *txtFile)
 
 	if (btnSelectQSLrcvd->value())   fprintf (txtFile, "%-10s", "QSLR");
 	if (btnSelectQSLsent->value())   fprintf (txtFile, "%-10s", "QSLS");
+
+	if (btnSelecteQSLrcvd->value())   fprintf (txtFile, "%-10s", "EQSLR");
+	if (btnSelecteQSLsent->value())   fprintf (txtFile, "%-10s", "EQSLS");
+
 	if (btnSelectLOTWrcvd->value())  fprintf (txtFile, "%-10s", "LOTWR");
-	if (btnSelectLOTWLsent->value())  fprintf (txtFile, "%-10s", "LOTWS");
+	if (btnSelectLOTWsent->value())  fprintf (txtFile, "%-10s", "LOTWS");
+
 	if (btnSelectNotes->value())     fprintf (txtFile, "%-80s", "NOTES");
 	if (btnSelectSerialIN->value())  fprintf (txtFile, "%-7s", "SRX");
 	if (btnSelectSerialOUT->value()) fprintf (txtFile, "%-7s", "STX");
@@ -299,9 +314,9 @@ int cTextFile::writeTXTFile (const char *fname, cQsoDb *db) {
 				if (btnSelectFreq->value())
 					fprintf (txtFile, "%-12s", pRec->getField(FREQ));
 				if (btnSelectMode->value()) {
-					fprintf (txtFile, "%-12s", adif2export(pRec->getField(MODE)).c_str());
-					if (!adif2submode(pRec->getField(MODE)).empty())
-						fprintf (txtFile, "%-12s", adif2submode(pRec->getField(MODE)).c_str());
+					fprintf (txtFile, "%-12s", adif2export(pRec->getField(ADIF_MODE)).c_str());
+					if (!adif2submode(pRec->getField(ADIF_MODE)).empty())
+						fprintf (txtFile, "%-12s", adif2submode(pRec->getField(ADIF_MODE)).c_str());
 				}
 				if (btnSelectTX_pwr->value())
 					fprintf (txtFile, "%-8s", pRec->getField(TX_PWR));
@@ -335,9 +350,13 @@ int cTextFile::writeTXTFile (const char *fname, cQsoDb *db) {
 					fprintf (txtFile, "%-10s", pRec->getField(QSLRDATE));
 				if (btnSelectQSLsent->value())
 					fprintf (txtFile, "%-10s", pRec->getField(QSLSDATE));
+				if (btnSelecteQSLrcvd->value())
+					fprintf (txtFile, "%-10s", pRec->getField(EQSLRDATE));
+				if (btnSelecteQSLsent->value())
+					fprintf (txtFile, "%-10s", pRec->getField(EQSLSDATE));
 				if (btnSelectLOTWrcvd->value())
 					fprintf (txtFile, "%-10s", pRec->getField(LOTWRDATE));
-				if (btnSelectLOTWLsent->value())
+				if (btnSelectLOTWsent->value())
 					fprintf (txtFile, "%-10s", pRec->getField(LOTWSDATE));
 				if (btnSelectNotes->value()) {
 					string temp = pRec->getField(NOTES);
